@@ -5,19 +5,22 @@ use warnings;
 use Exporter 'import';
 use List::Util 'first';
 
-our $VERSION   = '0.01014';
-our @EXPORT_OK = qw( get_header set_header remove_header has_header );
+our $VERSION   = '0.01015';
+our @EXPORT_OK = qw( get_header set_header delete_header exists_header );
 
 sub new {
-    require Blosxom::Header::Object;
+    my $class      = __PACKAGE__ . '::Prototype';
     my $header_ref = $_[1];
-
-    Blosxom::Header::Object->new(
-        get    => sub { get_header( $header_ref, @_ )    },
-        set    => sub { set_header( $header_ref, @_ )    },
-        has    => sub { has_header( $header_ref, @_ )    },
-        remove => sub { remove_header( $header_ref, @_ ) },
+    my %method     = (
+        get    => sub { get_header(    $header_ref, @_ ) },
+        set    => sub { set_header(    $header_ref, @_ ) },
+        exists => sub { exists_header( $header_ref, @_ ) },
+        delete => sub { delete_header( $header_ref, @_ ) },
     );
+
+    eval "require $class";
+
+    return $class->new( %method );
 }
 
 sub get_header {
@@ -43,7 +46,7 @@ sub set_header {
     return;
 }
 
-sub has_header {
+sub exists_header {
     my $header_ref = shift;
     my $key        = _lc( shift );
 
@@ -55,7 +58,7 @@ sub has_header {
     return 0;
 }
 
-sub remove_header {
+sub delete_header {
     my $header_ref = shift;
     my $key        = _lc( shift );
 
@@ -89,26 +92,20 @@ Blosxom::Header - Missing interface to modify HTTP headers
 
 =head1 SYNOPSIS
 
-  # blosxom.cgi
-  package blosxom;
-  our $header = { foo => 'bar' };
-
-  # plugins/foo
-  package foo;
-  use Blosxom::Header qw(get_header set_header has_header remove_header);
+  use Blosxom::Header qw(get_header set_header exists_header delete_header);
 
   # Functional interface
   my $value = get_header( $blosxom::header, 'foo' );
-  my $bool  = has_header( $blosxom::header, 'foo' );
+  my $bool  = exists_header( $blosxom::header, 'foo' );
   set_header( $blosxom::header, 'bar' => 'baz' );
-  remove_header( $blosxom::header, 'foo' );
+  delete_header( $blosxom::header, 'foo' );
 
-  # OO interface
+  # Object-oriented interface
   my $h     = Blosxom::Header->new( $blosxom::header );
   my $value = $h->get('foo');
-  my $bool  = $h->has('foo');
+  my $bool  = $h->exists('foo');
   $h->set( bar => 'baz' );
-  $h->remove('foo');
+  $h->delete('foo');
 
 =head1 DESCRIPTION
 
@@ -125,17 +122,7 @@ When plugin developers modify HTTP headers, they must write as follows:
 It's obviously bad practice.
 Blosxom misses the interface to modify them.
 
-This module provieds you an OO interface:
-
-  use Blosxom::Header;
-  my $h = Blosxom::Header->new( $blosxom::header );
-  $h->set( 'Status' => '304 Not Modified' );
-
-or a functional one:
-
-  use Blosxom::Header qw(set_header);
-  set_header( $blosxom::header, 'Status' => '304 Not Modified' );
-
+This module provieds you a functional one or an object-oriented one.
 You don't need to mind whether to put a hyphen before a key,
 nor whether to make a key lowercased or L<camelized|String::CamelCase>.
 
@@ -153,11 +140,11 @@ Returns a value of the specified HTTP header.
 
 Sets a value of the specified HTTP header.
 
-=item has_header( $blosxom::header, 'foo' )
+=item exists_header( $blosxom::header, 'foo' )
 
 Returns a Boolean value telling whether the specified HTTP header exists.
 
-=item remove_header( $blosxom::header, 'foo' )
+=item delete_header( $blosxom::header, 'foo' )
 
 Deletes the specified element from HTTP headers.
 
@@ -171,17 +158,17 @@ Deletes the specified element from HTTP headers.
 
 Creates a new Blosxom::Header object.
 
-=item $h->has( 'foo' )
+=item $h->exists( 'foo' )
 
-A synonym for has_header.
+A synonym for exists_header.
 
 =item $h->get( 'foo' )
 
 A synonym for get_header.
 
-=item $h->remove( 'foo' )
+=item $h->delete( 'foo' )
 
-A synonym for remove_header.
+A synonym for delete_header.
 
 =item $h->set( 'foo' => 'bar' )
 
@@ -200,7 +187,7 @@ L<CGI>::header recognizes the following parameters.
 Can be used to turn the page into an attachment.
 Represents suggested name for the saved file.
 
-  $h->set(attachment => 'foo.png');
+  $h->set( attachment => 'foo.png' );
 
 In this case, the outgoing header will be formatted as:
 
@@ -211,15 +198,15 @@ In this case, the outgoing header will be formatted as:
 Represents the character set sent to the browser.
 If not provided, defaults to ISO-8859-1.
 
-  $h->set(charset => 'utf-8');
+  $h->set( charset => 'utf-8' );
 
 =item cookie
 
 Represents the Set-Cookie header.
 The parameter can be an arrayref or a string.
 
-  $h->set(cookie => [$cookie1, $cookie2]);
-  $h->set(cookie => $cookie);
+  $h->set( cookie => [$cookie1, $cookie2] );
+  $h->set( cookie => $cookie );
 
 Refer to L<CGI>::cookie.
 
@@ -229,16 +216,16 @@ Represents the Expires header.
 You can specify an absolute or relative expiration interval.
 The following forms are all valid for this field.
 
-  $h->set(expires => '+30s'); # 30 seconds from now
-  $h->set(expires => '+10m'); # ten minutes from now
-  $h->set(expires => '+1h' ); # one hour from now
-  $h->set(expires => '-1d' ); # yesterday
-  $h->set(expires => 'now' ); # immediately
-  $h->set(expires => '+3M' ); # in three months
-  $h->set(expires => '+10y'); # in ten years time
+  $h->set( expires => '+30s' ); # 30 seconds from now
+  $h->set( expires => '+10m' ); # ten minutes from now
+  $h->set( expires => '+1h'  ); # one hour from now
+  $h->set( expires => '-1d'  ); # yesterday
+  $h->set( expires => 'now'  ); # immediately
+  $h->set( expires => '+3M'  ); # in three months
+  $h->set( expires => '+10y' ); # in ten years time
 
   # at the indicated time & date
-  $h->set(expires => 'Thu, 25 Apr 1999 00:40:33 GMT');
+  $h->set( expires => 'Thu, 25 Apr 1999 00:40:33 GMT' );
 
 =item nph
 
@@ -246,15 +233,15 @@ If set to a true value,
 will issue the correct headers to work with
 a NPH (no-parse-header) script:
 
-  $h->set(nph => 1);
+  $h->set( nph => 1 );
 
 =item p3p
 
 Will add a P3P tag to the outgoing header.
 The parameter can be an arrayref or a space-delimited string.
 
-  $h->set(p3p => [qw(CAO DSP LAW CURa)]);
-  $h->set(p3p => 'CAO DSP LAW CURa');
+  $h->set( p3p => [qw(CAO DSP LAW CURa)] );
+  $h->set( p3p => 'CAO DSP LAW CURa' );
 
 In either case, the outgoing header will be formatted as:
 
@@ -264,7 +251,7 @@ In either case, the outgoing header will be formatted as:
 
 Represents the Content-Type header.
 
-  $h->set(type => 'text/plain');
+  $h->set( type => 'text/plain' );
 
 =back
 
